---
layout: article
title: Basic Concepts
categories: [photon-server, getting_started]
tags: [how-to, quickstart, setup, operations]
---
{% include globals %}

When getting to know Photon the following basic concepts are of much importance.

### Applications

An Application is the server side logic for a game. All features of a
game (e.g. remote procedure calls, data storing, etc.) are implemented
in a Photon application. The C\# source is compiled and the resulting
assemblies are loaded by Photon's native core. The Photon Core uses
configuration files to setup applications and define start parameters.

Usually, all logic of a game is provided in a single application. Still,
Photon is able to run several applications at the same time. Each
application can have a different task. For example, a separate
application can be made to send out policy files for web-based clients.
Being a separate application you can add its functionality by running
the Policy application cooperatively next to your game logic.

On connects, a client choses the application is wants to use by simply
providing the application's name.

### Game Logic

The game logic defines how a client can interact with the server. It
implements operations, events and anything that the server does by
itself.

A good basis for room based games is provided as ["Lite"
application](/liteandlitelobbyaddon), found in the SDK folder
src-server/Lite. It does not know (your) game's logic (yet), but
provides rooms in which players can communicate easily. The application
"LiteLobby" extends Lite with lists of rooms, if you want your users to
select a room manually.

If your game is going to be a single, huge world, the [MMO Demo
Application](/mmo) is a good basis for it. This application handles
interest management for your clients and provides classes for items,
properties, actors and more.

Alternatively any game logic can be developed directly on top of the C\#
framework. The entry point for this is the Application class, defined in
the Photon.Socketserver.dll.

### Operations

An Operation is Photon's equivalent to a remote procedure call. Photon
clients use Operation calls for anything they want to get done.

Operations and all of their parameters are defined in the server side
Application as needed. Clients can call any Operation by setting up a
Hashtable with keys and values fitting the Operation's conventions. The
client and server frameworks take care of serialization, transfer and
deserialization.

Each Operation can also provide a result. This is one way to provide a
client with requested data. Of course, the result can be skipped which
saves bandwidth.

Operation calls and results are a thing between one client and the
server. The other clients won't know about these.

### Events

Photon Events are messages for clients. Each event is typed by a byte
code and carries game updates. The Lite application defines several
events but it's possible to define custom events purely on the client
side.

Unlike Operation results, a received Event is most likely caused another
client's Operation call. This means: Events might arrive anytime. Lite
sends events when someone joins or leaves a room.

The Operation RaiseEvent (in Lite) is what makes Events truly universal:
Any client can create new Events by putting together a Hashtable with
the data and applying a code on sending it. Game data can be sent
without any need to change the server.

Of course, for more elaborate server side reaction to events, custom
Operations can be defined which check event data, compile it or create
other events.

### Connections and Timeouts

Unlike plain UDP, Photon's reliable UDP protocol establishes a
connection between server and clients: Commands within a UDP package
have sequence numbers and a flag if they are reliable. If so, the
receiving end has to acknowledge the command. Reliable commands are
repeated in short intervals until an acknowledgement arrives. If it does
not arrive, the connection is timed out.

Both sides monitor this connection independently from their perspective.
Both sides have their rules to decide if the other is still available.

If a timeouts is detected, a disconnect happens on that side of the
connection. As we think the other side does not respond anymore, no
message is sent to it. This is why timeout disconnects are one sided and
not synchronous.
